@@ -3,7 +3,7 @@ BEGIN {
   $Hailo::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Hailo::VERSION = '0.51';
+  $Hailo::VERSION = '0.52';
 }
 
 use 5.010;
@@ -128,6 +128,7 @@ for my $k (keys %has) {
     no strict 'refs';
     *{"_build__${k}"} = sub {
         my ($self) = @_;
+
         my $obj = $self->_new_class(
             $name,
             $self->$method_class,
@@ -141,7 +142,26 @@ for my $k (keys %has) {
                  : ()),
                 (($k ~~ [ qw< storage > ] and defined $self->brain)
                  ? (
-                     hailo => $self,
+                     hailo => do {
+                         require Scalar::Util;
+                         Scalar::Util::weaken(my $s = $self);
+
+                         my %callback = (
+                             has_custom_order           => sub { $s->_custom_order },
+                             has_custom_tokenizer_class => sub { $s->_custom_tokenizer_class },
+                             set_order => sub {
+                                 my ($db_order) = @_;
+                                 $s->order($db_order);
+                                 $s->_engine->order($db_order);
+                             },
+                             set_tokenizer_class => sub {
+                                 my ($db_tokenizer_class) = @_;
+                                 $s->tokenizer_class($db_tokenizer_class);
+                             },
+                         );
+
+                         \%callback;
+                     },
                      brain => $self->brain
                  )
                  : ()),
@@ -187,8 +207,8 @@ sub _new_class {
 }
 
 sub save {
-    my ($self) = @_;
-    $self->_storage->save(@_);
+    my ($self, @args) = @_;
+    $self->_storage->save(@args);
     return;
 }
 
